==> 1.0.13.tar.gz: lib/src/core/widgets/search/ModernFormSearchAppBar.dart <==
part of modern_form_core;

class ModernFormSearchAppBar extends StatefulWidget
    implements PreferredSizeWidget {
  final String title;
  final String? hintText;
  final void Function() onCancelSearch;
  final Function(String text) onChanged;
  final Widget? action;
  final Widget? child;

  const ModernFormSearchAppBar({
    Key? key,
    required this.title,
    required this.onCancelSearch,
    required this.onChanged,
    this.action,
    this.hintText,
    this.child,
  }) : super(key: key);
  @override
  _ModernFormSearchAppBarState createState() => _ModernFormSearchAppBarState();

  @override
  Size get preferredSize => Size.fromHeight(56.0);
}

class _ModernFormSearchAppBarState extends State<ModernFormSearchAppBar> {
  final TextEditingController searchController = TextEditingController();
  final FocusNode searchFocus = FocusNode();
  bool isSearch = false;

  @override
  void initState() {
    super.initState();
    KeyboardVisibilityController().onChange.listen((bool visible) {
      if (!visible) {
        searchFocus.unfocus();
      }
    });
  }

  @override
  Widget build(BuildContext context) {
    return !isSearch
        ? AppBar(
            title: Text(widget.title),
            actions: [
              widget.action != null ? widget.action! : Container(),
              IconButton(
                icon: Icon(Icons.search),
                onPressed: () {
                  setState(() {
                    isSearch = true;
                  });
                },
              ),
            ],
          )
        : ModernFormSearchWidget(
            controller: searchController,
            focus: searchFocus,
            color: Theme.of(context).primaryColor,
            hintText: widget.hintText ?? "",
            onCancelSearch: () {
              setState(() {
                widget.onCancelSearch();
                searchController.clear();
                isSearch = false;
              });
            },
            onClear: () {
              widget.onCancelSearch();
              searchController.clear();
            },
            onChanged: (text) {
              widget.onChanged(text);
            },
            child: widget.child,
          );
  }
}

==> 1.6.0.tar.gz: lib/src/core/widgets/search/ModernFormSearchAppBar.dart <==
part of modern_form_core;

class ModernFormSearchAppBar extends StatefulWidget
    implements PreferredSizeWidget {
  final String title;
  final String? hintText;
  final void Function()? onCancelSearch;
  final Function(String text)? onChanged;
  final Widget? action;
  final Widget? child;

  const ModernFormSearchAppBar({
    Key? key,
    required this.title,
    required this.onCancelSearch,
    required this.onChanged,
    this.action,
    this.hintText,
    this.child,
  }) : super(key: key);
  @override
  _ModernFormSearchAppBarState createState() => _ModernFormSearchAppBarState();

  @override
  Size get preferredSize => Size.fromHeight(56.0);
}

class _ModernFormSearchAppBarState extends State<ModernFormSearchAppBar> {
  final TextEditingController searchController = TextEditingController();
  final FocusNode searchFocus = FocusNode();
  bool isSearch = false;

  @override
  void initState() {
    super.initState();
    KeyboardVisibilityController().onChange.listen((bool visible) {
      if (!visible) {
        searchFocus.unfocus();
      }
    });
  }

  @override
  Widget build(BuildContext context) {
    return !isSearch
        ? AppBar(
            title: Text(widget.title),
            actions: [
              widget.action != null ? widget.action! : Container(),
              IconButton(
                icon: Icon(Icons.search),
                onPressed: () {
                  setState(() {
                    isSearch = true;
                  });
                },
              ),
            ],
          )
        : ModernFormSearchWidget(
            controller: searchController,
            focus: searchFocus,
            color: Theme.of(context).primaryColor,
            hintText: widget.hintText ?? "",
            onCancelSearch: () {
              setState(() {
                if (widget.onCancelSearch != null) {
                  widget.onCancelSearch!();
                }
                searchController.clear();
                isSearch = false;
              });
            },
            onClear: () {
              if (widget.onCancelSearch != null) {
                widget.onCancelSearch!();
              }
              searchController.clear();
            },
            onChanged: (text) {
              if (widget.onChanged != null) {
                widget.onChanged!(text);
              }
            },
            child: widget.child,
          );
  }
}
